@@ -1,5 +1,6 @@
 import logging
 import os
+from pathlib import Path
 
 from flatpaksync.commands.command import command
 from flatpaksync.configs.write import write as writeconfig
@@ -7,6 +8,8 @@ from flatpaksync.configs.read import read as readconfig
 
 from flatpaksync.structs.app import app
 
+mylog = logging.getLogger("fps")
+
 class add(command):
 
     def __init__(self):
@@ -14,6 +17,10 @@ class add(command):
 
     def execute(self, repo, appid):
 
+        if self.conf.endswith(".config/flatpak-sync/flatpak.json"):
+            confPath = os.path.dirname(os.path.realpath(self.conf)) 
+            Path(confPath).mkdir(parents=True, exist_ok=True)
+
         config = readconfig(self.conf)
         if config.read():
             settings=config.getSettings()
@@ -21,8 +28,8 @@ class add(command):
             applist=config.getAppList()
 
                 # Don't add Base Apps
-            if appid.endswith("BaseApp"):
-                logging.warn("Unnecessary to add base apps")
+            if appid.endswith(".BaseApp"):
+                mylog.warn("Unnecessary to add base apps")
             else:
                 addApp = app(appid, repo)
                 applist.add(addApp)
@@ -34,10 +41,10 @@ class add(command):
                 wconfig.setAppList(applist)
 
                 if wconfig.write():
-                    logging.info('Successfully wrote configuration')
+                    mylog.info('Successfully wrote configuration')
                 else:
-                    logging.error('Failed to write configuration')
+                    mylog.error('Failed to write configuration')
 
         else:
-            logging.error('Failed to read configuration')
+            mylog.error('Failed to read configuration')
 
