@@ -3,11 +3,15 @@ import os
 
 from flatpaksync.flatpakcmd import flatpakcmd
 
+mylog = logging.getLogger("fps")
+
 class command():
 
     def __init__(self):
         self.dryrun = False
 
+        logging.basicConfig(format='%(levelname)s: %(message)s', level=logging.INFO)
+
         self.conf = os.environ['HOME'] + '/' + ".config/flatpak-sync/flatpak.json"
 
 
@@ -18,10 +22,10 @@ class command():
 
     def setDebug(self, isVerbose):
         if isVerbose:
-            logging.basicConfig(format='%(levelname)s: %(message)s', level=logging.DEBUG)
-            logging.debug("Verbose mode enabled")
+            mylog.setLevel(logging.DEBUG)
+            mylog.debug("Verbose mode enabled")
         else:
-            logging.basicConfig(format='%(levelname)s: %(message)s', level=logging.INFO)
+            mylog.setLevel(logging.INFO)
 
 
     def setDryRun(self, isDryrun):
@@ -33,8 +37,8 @@ class command():
         if fp.isInstalled() == False:
             sys.exit("Unable to find flatpak! Are you sure flatpak is installed?")
             
-        logging.debug("Flatpak installed: {}".format(fp.isInstalled()))
-        logging.debug(fp.getVersion())
-        logging.debug("Configuration file: {}".format(self.conf))
+        mylog.debug("Flatpak installed: {}".format(fp.isInstalled()))
+        mylog.debug(fp.getVersion())
+        mylog.debug("Configuration file: {}".format(self.conf))
 
 
