@@ -6,6 +6,7 @@ from flatpaksync.configs.read import read as readconfig
 
 from flatpaksync.structs.app import app
 
+mylog = logging.getLogger("fps")
 
 class remove(command):
 
@@ -35,12 +36,12 @@ class remove(command):
                 wconfig.setAppList(applist)
 
                 if wconfig.write():
-                    logging.info('Successfully wrote configuration')
+                    mylog.info('Successfully wrote configuration')
                 else:
-                    logging.error('Failed to write configuration')
+                    mylog.error('Failed to write configuration')
             else:
-                logging.warn("Unable to find application/repo {}".format(appid))
+                mylog.warn("Unable to find application/repo {}".format(appid))
 
         else:
-            logging.error('Failed to read configuration')
+            mylog.error('Failed to read configuration')
 
