@@ -6,8 +6,11 @@ from flatpaksync.configs.read import read as readconfig
 
 from flatpaksync.structs.app import app
 from flatpaksync.actions.app import app as appaction
+from flatpaksync.actions.repo import repo as repoaction
 from flatpaksync.actions.permission import permission as permissionaction
 
+mylog = logging.getLogger("fps")
+
 class run(command):
 
     def __init__(self):
@@ -22,31 +25,39 @@ class run(command):
             repolist=config.getRepoList()
             applist=config.getAppList()
 
+            repoact = repoaction()
+            for repo in repolist.getAll():
+                
+                if not repoact.isInstalled(repo):
+                    my.debug('Installing {} repo'.format(repo.getName()))
+                    if not repoact.add(repo):
+                        my.error('Failed to install {} repo'.format(repo.getName()))
+
                 # Install Applications
             for app in applist.getAll():
                 action=appaction()
                 permaction=permissionaction()
 
                 if action.isInstalled(app):
-                    logging.debug('{} already installed'.format(app.getAppId()))
+                    mylog.debug('{} already installed'.format(app.getAppId()))
                 else:
                     if self.dryrun:
-                        logging.info('{} to be installed'.format(app.getAppId()))
+                        mylog.info('{} to be installed'.format(app.getAppId()))
                     elif action.install(app):
-                        logging.info('{} installation successful'.format(app.getAppId()))
+                        mylog.info('{} installation successful'.format(app.getAppId()))
                     else:
-                        logging.error('{} installation failed'.format(app.getAppId()))
+                        mylog.error('{} installation failed'.format(app.getAppId()))
 
                 perms = app.getPermissions()
                 if perms.getCount() > 0:
-                    logging.debug('{} has overriding permissions'.format(app.getAppId()))
+                    mylog.debug('{} has overriding permissions'.format(app.getAppId()))
                     for permission in perms.getAll():
                         if permaction.override(app, permission):
-                            logging.debug(" permission set")
+                            mylog.debug(" permission set")
                         else:
-                            logging.error("{} failed to set permission '{}'".format(app.getAppId(), permission.getPermission()))
+                            mylog.error("{} failed to set permission '{}'".format(app.getAppId(), permission.getPermission()))
 
                 #else
-                #    logging.debug('{} has no overriding permissions'.format(app.getAppId()))
+                #    mylog.debug('{} has no overriding permissions'.format(app.getAppId()))
         else:
-            logging.info('failed to read configuration')
+            mylog.info('failed to read configuration')
