@@ -9,6 +9,7 @@ class repo:
     def __init__(self, name = '', location = ''):
         self.name = name
         self.location = location
+        self.type = ''
 
     def setName(self, name: str) -> None:
         self.name = name
@@ -16,6 +17,12 @@ class repo:
     def setLocation(self, location: str) -> None:
         self.location = location
 
+    def setType(self, installtype: str) -> None:
+        self.type = installtype
+
+    def getType(self) -> str:
+        return self.type
+
     def getName(self) -> str:
         return self.name
 
